@@ -10,13 +10,13 @@ from qiime2.plugin import (Plugin, Int, Float, Range, Metadata, Str, Bool,
                            Choices, MetadataColumn, Categorical, List,
                            Citations, TypeMatch, TypeMap)
 
-import q2_feature_table
 from q2_types.feature_table import (
     FeatureTable, Frequency, RelativeFrequency, PresenceAbsence, Composition)
 from q2_types.feature_data import (
     FeatureData, Sequence, Taxonomy, AlignedSequence)
-from .examples import (feature_table_merge_example,
-                       feature_table_merge_three_tables_example)
+
+import q2_feature_table
+import q2_feature_table._examples as ex
 
 citations = Citations.load('citations.bib', package='q2_feature_table')
 plugin = Plugin(
@@ -41,8 +41,7 @@ plugin.methods.register_function(
         'sampling_depth': ('The total frequency that each sample should be '
                            'rarefied to. Samples where the sum of frequencies '
                            'is less than the sampling depth will be not be '
-                           'included in the resulting table unless '
-                           'subsampling is performed with replacement.'),
+                           'included in the resulting table.'),
         'with_replacement': ('Rarefy with replacement by sampling from the '
                              'multinomial distribution instead of rarefying '
                              'without replacement.')
@@ -171,7 +170,8 @@ plugin.methods.register_function(
     },
     name="Group samples or features by a metadata column",
     description="Group samples or features in a feature table using metadata "
-                "to define the mapping of IDs to a group."
+                "to define the mapping of IDs to a group.",
+    examples={'group_samples': ex.feature_table_group_samples}
 )
 
 i_table, p_overlap_method, o_table = TypeMap({
@@ -204,8 +204,10 @@ plugin.methods.register_function(
     },
     name="Combine multiple tables",
     description="Combines feature tables using the `overlap_method` provided.",
-    examples={'basic': feature_table_merge_example,
-              'three_tables': feature_table_merge_three_tables_example},
+    examples={'feature_table_merge_two_tables':
+              ex.feature_table_merge_two_tables,
+              'feature_table_merge_three_tables':
+              ex.feature_table_merge_three_tables},
 )
 
 
@@ -227,7 +229,10 @@ plugin.methods.register_function(
     description="Combines feature data objects which may or may not "
                 "contain data for the same features. If different feature "
                 "data is present for the same feature id in the inputs, "
-                "the data from the first will be propagated to the result."
+                "the data from the first will be propagated to the result.",
+    examples={
+        'feature_table_merge_seqs': ex.feature_table_merge_seqs
+    }
 )
 
 
@@ -249,7 +254,10 @@ plugin.methods.register_function(
     description="Combines a pair of feature data objects which may or may not "
                 "contain data for the same features. If different feature "
                 "data is present for the same feature id in the inputs, "
-                "the data from the first will be propagated to the result."
+                "the data from the first will be propagated to the result.",
+    examples={
+        'feature_table_merge_taxa': ex.feature_table_merge_taxa
+    }
 )
 
 T1 = TypeMatch([Frequency, RelativeFrequency, PresenceAbsence, Composition])
@@ -338,7 +346,17 @@ plugin.methods.register_function(
     description="Filter samples from table based on frequency and/or "
                 "metadata. Any features with a frequency of zero after sample "
                 "filtering will also be removed. See the filtering tutorial "
-                "on https://docs.qiime2.org for additional details."
+                "on https://docs.qiime2.org for additional details.",
+    examples={
+        'filter_to_subject1': ex.feature_table_filter_samples_to_subject1,
+        'filter_to_skin': ex.feature_table_filter_samples_to_skin,
+        'filter_to_subject1_gut':
+        ex.feature_table_filter_samples_to_subject1_gut,
+        'filter_to_gut_or_abx': ex.feature_table_filter_samples_to_gut_or_abx,
+        'filter_to_subject1_not_gut':
+        ex.feature_table_filter_samples_to_subject1_not_gut,
+        'filter_min_features': ex.feature_table_filter_samples_min_features,
+        'filter_min_frequency': ex.feature_table_filter_samples_min_frequency}
 )
 
 plugin.methods.register_function(
@@ -367,7 +385,11 @@ plugin.methods.register_function(
                  "relative abundance of at least `abundance` in at least "
                  "`prevalence` number of samples). Any samples with a "
                  "frequency of zero after feature filtering will also be "
-                 "removed.")
+                 "removed."),
+    examples={
+        'feature_table_filter_features_conditionally':
+        ex.feature_table_filter_features_conditionally
+    }
 )
 
 
@@ -419,7 +441,11 @@ plugin.methods.register_function(
     description="Filter features from table based on frequency and/or "
                 "metadata. Any samples with a frequency of zero after feature "
                 "filtering will also be removed. See the filtering tutorial "
-                "on https://docs.qiime2.org for additional details."
+                "on https://docs.qiime2.org for additional details.",
+    examples={
+     'filter_features_min_samples':
+     ex.feature_table_filter_features_min_samples
+    }
 )
 
 
@@ -475,7 +501,10 @@ plugin.visualizers.register_function(
     input_descriptions={'table': 'The feature table to be summarized.'},
     parameter_descriptions={'sample_metadata': 'The sample metadata.'},
     name="Summarize table",
-    description="Generate visual and tabular summaries of a feature table."
+    description="Generate visual and tabular summaries of a feature table.",
+    examples={
+        'feature_table_summarize': ex.feature_table_summarize,
+    }
 )
 
 plugin.visualizers.register_function(
@@ -488,7 +517,10 @@ plugin.visualizers.register_function(
     description="Generate tabular view of feature identifier to sequence "
                 "mapping, including links to BLAST each sequence against "
                 "the NCBI nt database.",
-    citations=[citations['NCBI'], citations['NCBI-BLAST']]
+    citations=[citations['NCBI'], citations['NCBI-BLAST']],
+    examples={
+        'feature_table_tabulate_seqs': ex.feature_table_tabulate_seqs,
+    }
 )
 
 plugin.visualizers.register_function(
